"""The :mod:`pyrcn.preprocessing` module provides preprocessing utilities."""

# See https://github.com/TUD-STKS/PyRCN and for documentation.

from pyrcn.preprocessing._coates import Coates

__all__ = ('Coates',)
